@@ -28,7 +28,7 @@ get_by <- function(dm, lhs_name, rhs_name) {
     lhs_col <- dm_get_pk_impl(dm, lhs_name)
     rhs_col <- dm_get_fk_impl(dm, rhs_name, lhs_name)
   } else {
-    abort_tables_not_neighbours(lhs_name, rhs_name)
+    abort_tables_not_neighbors(lhs_name, rhs_name)
   }
 
   if (length(lhs_col) > 1 || length(rhs_col) > 1) abort_no_cycles()
